#############
Aldryn Search
#############

Aldryn Search is an application that acts like a bridge between django-haystack and django CMS.
It's also a great tool to hookup search capabilities to any Django application, especially
applications that make use of multilingual frameworks like django-hvad or django-parler. It's
designed with multiple languages in mind, and provides multiple helpers to easily search within a
language based set-up (like one core per language in solr).

Aldryn Search allows you to easily set up a search interface to django-cms and/or any Django app.

Aldryn Search is `open-source software <https://github.com/aldryn/aldryn-search>`_.

.. toctree::
   :maxdepth: 2

   introduction/index
   reference/index
